| Title: | Check if an 'externalptr' is a Null Pointer |
|---|---|
| Description: | Check if an 'externalptr' is a null pointer. R does currently not have a native function for that purpose. This package contains a C function that returns TRUE in case of a null pointer. |
| Authors: | Jonas Förster [aut, cre] |
| Maintainer: | Jonas Förster <[email protected]> |
| License: | GPL-3 |
| Version: | 1.0.2 |
| Built: | 2026-05-31 10:07:59 UTC |
| Source: | https://github.com/jonasfoe/isnullptr |
isnullptr checks if an object of type 'externalptr' is a null pointer.
isnullptr(pointer)isnullptr(pointer)
pointer |
object of type 'externalptr' |
TRUE if null pointer, FALSE otherwise
isnullptr(new("externalptr")) isnullptr("any_data")isnullptr(new("externalptr")) isnullptr("any_data")