Welcome to ClientVPS Mirrors

Help for package isnullptr
Title: Check if an 'externalptr' is a Null Pointer
Version: 1.0.2
Description: Check if an 'externalptr' is a null pointer. R does currently not have a native function for that purpose. This package contains a C function that returns TRUE in case of a null pointer.
Depends: R (≥ 3.0)
License: GPL-3
Encoding: UTF-8
RoxygenNote: 7.3.2
NeedsCompilation: yes
Packaged: 2024-07-07 18:16:39 UTC; jonas
Author: Jonas Förster [aut, cre]
Maintainer: Jonas Förster <jonasfoerster@gmail.com>
Repository: CRAN
Date/Publication: 2024-07-11 18:00:02 UTC

Check if an 'externalptr' is a null pointer

Description

isnullptr checks if an object of type 'externalptr' is a null pointer.

Usage

isnullptr(pointer)

Arguments

pointer

object of type 'externalptr'

Value

TRUE if null pointer, FALSE otherwise

Examples

isnullptr(new("externalptr"))
isnullptr("any_data")

Need a high-speed mirror for your open-source project?
Contact our mirror admin team at info@clientvps.com.

This archive is provided as a free public service to the community.
Proudly supported by infrastructure from VPSPulse , RxServers , BuyNumber , UnitVPS , OffshoreName and secure payment technology by ArionPay.